@@ -52,6 +52,7 @@ class ServerError(FedoraServiceError):
     This includes network errors and 500 response codes.
     '''
     def __init__(self, url, status, msg):
+        FedoraServiceError.__init__(self)
         self.filename = url
         self.code = status
         self.msg = msg
@@ -66,6 +67,7 @@ class AuthError(FedoraServiceError):
 class AppError(FedoraServiceError):
     '''Error condition that the server is passing back to the client.'''
     def __init__(self, name, message, extras=None):
+        FedoraServiceError.__init__(self)
         self.name = name
         self.message = message
         self.extras = extras
@@ -148,6 +150,7 @@ class DictContainer(dict):
 # We want people to be able to import fedora.client.*Client directly
 # pylint: disable-msg=W0611
 from fedora.client.proxyclient import ProxyClient
+from fedora.client.fasproxy import FasProxyClient
 from fedora.client.baseclient import BaseClient
 from fedora.client.fas2 import AccountSystem, FASError, CLAError
 from fedora.client.pkgdb import PackageDB, PackageDBError
@@ -158,5 +161,5 @@ from fedora.client.wiki import Wiki
 __all__ = ('FedoraServiceError', 'ServerError', 'AuthError', 'AppError',
         'FedoraClientError', 'DictContainer',
         'FASError', 'CLAError', 'BodhiClientException', 'PackageDBError',
-        'ProxyClient', 'BaseClient', 'AccountSystem', 'PackageDB',
-        'BodhiClient', 'Wiki')
+        'ProxyClient', 'FasProxyClient', 'BaseClient', 'AccountSystem',
+        'PackageDB', 'BodhiClient', 'Wiki')
