@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2007  Red Hat, Inc.
+# Copyright (C) 2009  Red Hat, Inc.
 # This file is part of python-fedora
 # 
 # python-fedora is free software; you can redistribute it and/or
@@ -180,6 +180,10 @@ class ProxyClient(object):
             If ProxyClient was created with session_as_cookie=False, a tuple
             of session_id and data instead.
         :rtype: tuple of session information and data from server
+
+        .. versionchanged:: 0.3.17
+            No longer send tg_format=json parameter.  We rely solely on the
+            Accept: application/json header now.
         '''
         self.log.debug(_('proxyclient.send_request: entered'))
         # Check whether we need to authenticate for this request
@@ -233,7 +237,7 @@ class ProxyClient(object):
 
         # Set standard headers
         headers = ['User-agent: %s' % self.useragent,
-                'Accept: text/javascript']
+                'Accept: application/json']
         request.setopt(pycurl.HTTPHEADER, headers)
 
         # If we have a session_id, send it
@@ -244,10 +248,6 @@ class ProxyClient(object):
                 session_id))
 
         complete_params = req_params or {}
-        # Note: tg_format=json is going away in the future as the Accept
-        # header should serve the same purpose in a more framework neutral
-        # manner.
-        complete_params['tg_format'] = 'json'
         if session_id:
             # Add the csrf protection token
             token = sha_constructor(session_id)
@@ -326,3 +326,5 @@ class ProxyClient(object):
         request.close()
         self.log.debug(_('proxyclient.send_request: exited'))
         return new_session, DictContainer(data)
+
+__all__ = (ProxyClient,)
