@@ -18,10 +18,11 @@
 #
 '''
 .. moduleauthor:: Ignacio Vazquez-Abrams <ivazquez@fedoraproject.org>
+.. moduleauthor:: Toshio Kuratomi <toshio@fedoraproject.org>
 '''
  
 from fedora.client import AuthError
-from fedora.django import connection, person_by_id, local
+from fedora.django import connection, person_by_id
 from fedora.django.auth.models import FasUser
 
 from django.contrib.auth.models import AnonymousUser
@@ -35,10 +36,9 @@ class FasBackend(ModelBackend):
                 auth = {'session_id': session_id}
             else:
                 auth = {'username': username, 'password': password}
-            session_id, userinfo = connection.send_request('user/view',
-                auth_params=auth)
-            local.session_id = session_id
-            user = FasUser.objects.user_from_fas(userinfo['person'])
+            session_id, userinfo = connection.get_user_info(auth_params=auth)
+            user = FasUser.objects.user_from_fas(userinfo)
+            user.session_id = session_id
             if user.is_active:
                 return user
         except AuthError:
@@ -48,6 +48,6 @@ class FasBackend(ModelBackend):
         try:
             userinfo = person_by_id(userid)
             if userinfo:
-                return FasUser.objects.user_from_fas(userinfo['person'])
+                return FasUser.objects.user_from_fas(userinfo)
         except AuthError:
             return AnonymousUser()
