@@ -18,6 +18,7 @@
 #
 '''
 .. moduleauthor:: Ignacio Vazquez-Abrams <ivazquez@fedoraproject.org>
+.. moduleauthor:: Toshio Kuratomi <toshio@fedoraproject.org>
 '''
 from fedora.client import AuthError
 from fedora.django import connection, person_by_id
@@ -48,8 +49,7 @@ def _syncdb_handler(sender, **kwargs):
     if verbosity > 0:
         print _('Loading FAS groups...')
     try:
-        gl = connection.send_request('group/list', 
-            auth_params={'username': settings.FAS_USERNAME,
+        gl = connection.group_list({'username': settings.FAS_USERNAME,
             'password': settings.FAS_PASSWORD})
     except AuthError:
         if verbosity > 0:
@@ -60,8 +60,9 @@ def _syncdb_handler(sender, **kwargs):
         for group in groups:
             _new_group(group)
         if verbosity > 0:
-            print _('FAS groups loaded. Don\'t forget to unset '
-                'FAS_USERNAME and FAS_PASSWORD.')
+            print _('FAS groups loaded. Don\'t forget to set '
+                'FAS_USERNAME and FAS_PASSWORD to a low-privilege '
+                'account.')
 
 class FasUserManager(authmodels.UserManager):
     def user_from_fas(self, user):
@@ -69,6 +70,9 @@ class FasUserManager(authmodels.UserManager):
         Creates a user in the table based on the structure returned
         by FAS
         """
+        log = open('/var/tmp/django.log', 'a')
+        log.write('in models user_from_fas\n')
+        log.close()
         d = {}
         for k, v in _fasmap.iteritems():
             d[v] = user[k]
@@ -82,18 +86,44 @@ class FasUserManager(authmodels.UserManager):
         if getattr(settings, 'FAS_GENERICEMAIL', True):
             u.email = u._get_email()
         u.save()
+        known_groups = []
+        for group in u.groups.values():
+            known_groups.append(group['id'])
+
+        fas_groups = []
         for group in user['approved_memberships']:
-            g = _new_group(group)
-            u.groups.add(g)
+            fas_groups.append(group['id'])
+
+        # This user has been added to one or more FAS groups
+        for group in (g for g in user['approved_memberships'] if g['id'] not in known_groups):
+            newgroup = _new_group(group)
+            u.groups.add(newgroup)
+
+        # This user has been removed from one or more FAS groups
+        for gid in known_groups:
+            found = False
+            for g in user['approved_memberships']:
+                if g['id'] == gid:
+                    found = True
+                    break
+            if not found:
+                u.groups.remove(authmodels.Group.objects.get(id=gid))
+
         u.save()
         return u
 
 class FasUser(authmodels.User):
     def _get_name(self):
+        log = open('/var/tmp/django.log', 'a')
+        log.write('in models _get_name\n')
+        log.close()
         userinfo = person_by_id(self.id)
         return userinfo['human_name']
 
     def _get_email(self):
+        log = open('/var/tmp/django.log', 'a')
+        log.write('in models _get_email\n')
+        log.close()
         return '%s@fedoraproject.org' % self.username
 
     name = property(_get_name)
@@ -101,4 +131,9 @@ class FasUser(authmodels.User):
     objects = FasUserManager()
 
     def get_full_name(self):
-        return self.name.strip()
+        log = open('/var/tmp/django.log', 'a')
+        log.write('in models get_full_name\n')
+        log.close()
+        if self.name:
+            return self.name.strip()
+        return self.username.strip()
